@@ -1,7 +1,7 @@
 /*
  * fsarchiver: Filesystem Archiver
  *
- * Copyright (C) 2008-2010 Francois Dupoux.  All rights reserved.
+ * Copyright (C) 2008-2012 Francois Dupoux.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -156,12 +156,11 @@ int generic_get_mntinfo(char *devname, int *readwrite, char *mntbuf, int maxmntb
     char temp[2048];
     char *saveptr;
     char *result;
-    int res;
     FILE *f;
     int i;
 
     // init
-    res=uname(&suname);
+    uname(&suname);
     *readwrite=-1; // unknown
     memset(mntbuf, 0, sizeof(mntbuf));
     memset(optbuf, 0, sizeof(optbuf));
