@@ -1,7 +1,7 @@
 /*
  * fsarchiver: Filesystem Archiver
  *
- * Copyright (C) 2008-2010 Francois Dupoux.  All rights reserved.
+ * Copyright (C) 2008-2012 Francois Dupoux.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -55,6 +55,9 @@ u64 check_prog_version(char *prog);
 #define FSA_EXT4_FEATURE_RO_COMPAT_GDT_CSUM        0x0010
 #define FSA_EXT4_FEATURE_RO_COMPAT_DIR_NLINK       0x0020
 #define FSA_EXT4_FEATURE_RO_COMPAT_EXTRA_ISIZE     0x0040
+#define FSA_EXT4_FEATURE_RO_COMPAT_QUOTA           0x0100
+#define FSA_EXT4_FEATURE_RO_COMPAT_BIGALLOC        0x0200
+#define FSA_EXT4_FEATURE_RO_COMPAT_METADATA_CSUM   0x0400
 
 /* for s_feature_incompat */
 #define FSA_EXT2_FEATURE_INCOMPAT_FILETYPE         0x0002
@@ -65,46 +68,62 @@ u64 check_prog_version(char *prog);
 #define FSA_EXT4_FEATURE_INCOMPAT_64BIT            0x0080
 #define FSA_EXT4_FEATURE_INCOMPAT_MMP              0x0100
 #define FSA_EXT4_FEATURE_INCOMPAT_FLEX_BG          0x0200
+#define FSA_EXT4_FEATURE_INCOMPAT_EA_INODE         0x0400
+#define FSA_EXT4_FEATURE_INCOMPAT_DIRDATA          0x1000
+#define FSA_EXT4_FEATURE_INCOMPAT_BG_USE_META_CSUM 0x2000
+#define FSA_EXT4_FEATURE_INCOMPAT_LARGEDIR         0x4000
+#define FSA_EXT4_FEATURE_INCOMPAT_INLINEDATA       0x8000
 
-#define FSA_EXT2_FEATURE_RO_COMPAT_SUPP            (FSA_EXT2_FEATURE_RO_COMPAT_SPARSE_SUPER| \
-                            FSA_EXT2_FEATURE_RO_COMPAT_LARGE_FILE| \
-                            FSA_EXT2_FEATURE_RO_COMPAT_BTREE_DIR)
-
+#define FSA_EXT2_FEATURE_COMPAT_SUPP               FSA_EXT2_FEATURE_COMPAT_EXT_ATTR
 #define FSA_EXT2_FEATURE_INCOMPAT_SUPP             (FSA_EXT2_FEATURE_INCOMPAT_FILETYPE| \
-                            FSA_EXT2_FEATURE_INCOMPAT_META_BG)
-
+                                                    FSA_EXT2_FEATURE_INCOMPAT_META_BG)
+#define FSA_EXT2_FEATURE_RO_COMPAT_SUPP            (FSA_EXT2_FEATURE_RO_COMPAT_SPARSE_SUPER| \
+                                                    FSA_EXT2_FEATURE_RO_COMPAT_LARGE_FILE| \
+                                                    FSA_EXT2_FEATURE_RO_COMPAT_BTREE_DIR)
 #define FSA_EXT2_FEATURE_INCOMPAT_UNSUPPORTED      ~FSA_EXT2_FEATURE_INCOMPAT_SUPP
 #define FSA_EXT2_FEATURE_RO_COMPAT_UNSUPPORTED     ~FSA_EXT2_FEATURE_RO_COMPAT_SUPP
 
-#define FSA_EXT3_FEATURE_RO_COMPAT_SUPP            (FSA_EXT2_FEATURE_RO_COMPAT_SPARSE_SUPER| \
-                            FSA_EXT2_FEATURE_RO_COMPAT_LARGE_FILE| \
-                            FSA_EXT2_FEATURE_RO_COMPAT_BTREE_DIR)
+#define FSA_EXT3_FEATURE_COMPAT_SUPP               FSA_EXT2_FEATURE_COMPAT_EXT_ATTR
 #define FSA_EXT3_FEATURE_INCOMPAT_SUPP             (FSA_EXT2_FEATURE_INCOMPAT_FILETYPE| \
-                            FSA_EXT3_FEATURE_INCOMPAT_RECOVER| \
-                            FSA_EXT2_FEATURE_INCOMPAT_META_BG)
+                                                    FSA_EXT3_FEATURE_INCOMPAT_RECOVER| \
+                                                    FSA_EXT2_FEATURE_INCOMPAT_META_BG)
+#define FSA_EXT3_FEATURE_RO_COMPAT_SUPP            (FSA_EXT2_FEATURE_RO_COMPAT_SPARSE_SUPER| \
+                                                    FSA_EXT2_FEATURE_RO_COMPAT_LARGE_FILE| \
+                                                    FSA_EXT2_FEATURE_RO_COMPAT_BTREE_DIR)
 #define FSA_EXT3_FEATURE_INCOMPAT_UNSUPPORTED      ~FSA_EXT3_FEATURE_INCOMPAT_SUPP
 #define FSA_EXT3_FEATURE_RO_COMPAT_UNSUPPORTED     ~FSA_EXT3_FEATURE_RO_COMPAT_SUPP
 
 // -------------- features supported by the current fsarchiver version --------------------
 #define FSA_FEATURE_COMPAT_SUPP                    (u64)(FSA_EXT2_FEATURE_COMPAT_DIR_PREALLOC| \
-                            FSA_EXT2_FEATURE_COMPAT_IMAGIC_INODES| \
-                            FSA_EXT3_FEATURE_COMPAT_HAS_JOURNAL| \
-                            FSA_EXT2_FEATURE_COMPAT_EXT_ATTR| \
-                            FSA_EXT2_FEATURE_COMPAT_RESIZE_INODE| \
-                            FSA_EXT2_FEATURE_COMPAT_DIR_INDEX| \
-                            FSA_EXT2_FEATURE_COMPAT_LAZY_BG)
-#define FSA_FEATURE_INCOMPAT_SUPP                  (u64)(FSA_EXT2_FEATURE_INCOMPAT_FILETYPE|\
-                            FSA_EXT3_FEATURE_INCOMPAT_JOURNAL_DEV|\
-                            FSA_EXT2_FEATURE_INCOMPAT_META_BG|\
-                            FSA_EXT3_FEATURE_INCOMPAT_RECOVER|\
-                            FSA_EXT4_FEATURE_INCOMPAT_EXTENTS|\
-                            FSA_EXT4_FEATURE_INCOMPAT_FLEX_BG)
+                                                         FSA_EXT2_FEATURE_COMPAT_IMAGIC_INODES| \
+                                                         FSA_EXT3_FEATURE_COMPAT_HAS_JOURNAL| \
+                                                         FSA_EXT2_FEATURE_COMPAT_EXT_ATTR| \
+                                                         FSA_EXT2_FEATURE_COMPAT_RESIZE_INODE| \
+                                                         FSA_EXT2_FEATURE_COMPAT_DIR_INDEX| \
+                                                         FSA_EXT2_FEATURE_COMPAT_LAZY_BG)
 #define FSA_FEATURE_RO_COMPAT_SUPP                 (u64)(FSA_EXT2_FEATURE_RO_COMPAT_SPARSE_SUPER|\
-                            FSA_EXT4_FEATURE_RO_COMPAT_HUGE_FILE|\
-                            FSA_EXT2_FEATURE_RO_COMPAT_LARGE_FILE|\
-                            FSA_EXT4_FEATURE_RO_COMPAT_DIR_NLINK|\
-                            FSA_EXT4_FEATURE_RO_COMPAT_EXTRA_ISIZE|\
-                            FSA_EXT4_FEATURE_RO_COMPAT_GDT_CSUM)
+                                                         FSA_EXT2_FEATURE_RO_COMPAT_LARGE_FILE|\
+                                                         FSA_EXT2_FEATURE_RO_COMPAT_BTREE_DIR|\
+                                                         FSA_EXT4_FEATURE_RO_COMPAT_HUGE_FILE|\
+                                                         FSA_EXT4_FEATURE_RO_COMPAT_GDT_CSUM|\
+                                                         FSA_EXT4_FEATURE_RO_COMPAT_DIR_NLINK|\
+                                                         FSA_EXT4_FEATURE_RO_COMPAT_EXTRA_ISIZE|\
+                                                         FSA_EXT4_FEATURE_RO_COMPAT_QUOTA|\
+                                                         FSA_EXT4_FEATURE_RO_COMPAT_BIGALLOC|\
+                                                         FSA_EXT4_FEATURE_RO_COMPAT_METADATA_CSUM)
+#define FSA_FEATURE_INCOMPAT_SUPP                  (u64)(FSA_EXT2_FEATURE_INCOMPAT_FILETYPE|\
+                                                         FSA_EXT3_FEATURE_INCOMPAT_RECOVER|\
+                                                         FSA_EXT3_FEATURE_INCOMPAT_JOURNAL_DEV|\
+                                                         FSA_EXT2_FEATURE_INCOMPAT_META_BG|\
+                                                         FSA_EXT4_FEATURE_INCOMPAT_EXTENTS|\
+                                                         FSA_EXT4_FEATURE_INCOMPAT_64BIT|\
+                                                         FSA_EXT4_FEATURE_INCOMPAT_MMP|\
+                                                         FSA_EXT4_FEATURE_INCOMPAT_FLEX_BG|\
+                                                         FSA_EXT4_FEATURE_INCOMPAT_EA_INODE|\
+                                                         FSA_EXT4_FEATURE_INCOMPAT_DIRDATA|\
+                                                         FSA_EXT4_FEATURE_INCOMPAT_BG_USE_META_CSUM|\
+                                                         FSA_EXT4_FEATURE_INCOMPAT_LARGEDIR|\
+                                                         FSA_EXT4_FEATURE_INCOMPAT_INLINEDATA)
 
 // EXT2_FLAG_SOFTSUPP_FEATURES not defined on old e2fsprogs versions
 #ifndef EXT2_FLAG_SOFTSUPP_FEATURES
